#ifndef NT2_INCLUDE_FUNCTIONS_MPOWER_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_MPOWER_HPP_INCLUDED

#include <nt2/linalg/include/functions/mpower.hpp>

#endif
